@@ -22,14 +22,14 @@ import sys
 from cliff import command
 from cliff import lister
 from cliff import show
-from keystoneclient.openstack.common.apiclient import exceptions as ksc_exc
+from keystoneclient import exceptions as ksc_exc
 
 from openstackclient.common import utils
 from openstackclient.i18n import _  # noqa
 
 
 class CreateDomain(show.ShowOne):
-    """Create domain command"""
+    """Create new domain"""
 
     log = logging.getLogger(__name__ + '.CreateDomain')
 
@@ -42,21 +42,20 @@ class CreateDomain(show.ShowOne):
         )
         parser.add_argument(
             '--description',
-            metavar='<domain-description>',
+            metavar='<description>',
             help='New domain description',
         )
         enable_group = parser.add_mutually_exclusive_group()
         enable_group.add_argument(
             '--enable',
-            dest='enabled',
             action='store_true',
-            default=True,
-            help='Enable domain')
+            help='Enable domain (default)',
+        )
         enable_group.add_argument(
             '--disable',
-            dest='enabled',
-            action='store_false',
-            help='Disable domain')
+            action='store_true',
+            help='Disable domain',
+        )
         parser.add_argument(
             '--or-show',
             action='store_true',
@@ -68,11 +67,15 @@ class CreateDomain(show.ShowOne):
         self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
 
+        enabled = True
+        if parsed_args.disable:
+            enabled = False
+
         try:
             domain = identity_client.domains.create(
                 name=parsed_args.name,
                 description=parsed_args.description,
-                enabled=parsed_args.enabled,
+                enabled=enabled,
             )
         except ksc_exc.Conflict as e:
             if parsed_args.or_show:
@@ -87,7 +90,7 @@ class CreateDomain(show.ShowOne):
 
 
 class DeleteDomain(command.Command):
-    """Delete domain command"""
+    """Delete domain"""
 
     log = logging.getLogger(__name__ + '.DeleteDomain')
 
@@ -96,7 +99,7 @@ class DeleteDomain(command.Command):
         parser.add_argument(
             'domain',
             metavar='<domain>',
-            help='Name or ID of domain to delete',
+            help='Domain to delete (name or ID)',
         )
         return parser
 
@@ -110,7 +113,7 @@ class DeleteDomain(command.Command):
 
 
 class ListDomain(lister.Lister):
-    """List domain command"""
+    """List domains"""
 
     log = logging.getLogger(__name__ + '.ListDomain')
 
@@ -126,7 +129,7 @@ class ListDomain(lister.Lister):
 
 
 class SetDomain(command.Command):
-    """Set domain command"""
+    """Set domain properties"""
 
     log = logging.getLogger(__name__ + '.SetDomain')
 
@@ -135,28 +138,26 @@ class SetDomain(command.Command):
         parser.add_argument(
             'domain',
             metavar='<domain>',
-            help='Name or ID of domain to change',
+            help='Domain to modify (name or ID)',
         )
         parser.add_argument(
             '--name',
-            metavar='<new-domain-name>',
+            metavar='<name>',
             help='New domain name',
         )
         parser.add_argument(
             '--description',
-            metavar='<domain-description>',
+            metavar='<description>',
             help='New domain description',
         )
         enable_group = parser.add_mutually_exclusive_group()
         enable_group.add_argument(
             '--enable',
-            dest='enabled',
             action='store_true',
-            help='Enable domain (default)',
+            help='Enable domain',
         )
         enable_group.add_argument(
             '--disable',
-            dest='disabled',
             action='store_true',
             help='Disable domain',
         )
@@ -172,9 +173,10 @@ class SetDomain(command.Command):
             kwargs['name'] = parsed_args.name
         if parsed_args.description:
             kwargs['description'] = parsed_args.description
-        if parsed_args.enabled:
+
+        if parsed_args.enable:
             kwargs['enabled'] = True
-        if parsed_args.disabled:
+        if parsed_args.disable:
             kwargs['enabled'] = False
 
         if not kwargs:
@@ -185,7 +187,7 @@ class SetDomain(command.Command):
 
 
 class ShowDomain(show.ShowOne):
-    """Show domain command"""
+    """Display domain details"""
 
     log = logging.getLogger(__name__ + '.ShowDomain')
 
@@ -194,7 +196,7 @@ class ShowDomain(show.ShowOne):
         parser.add_argument(
             'domain',
             metavar='<domain>',
-            help='Name or ID of domain to display',
+            help='Domain to display (name or ID)',
         )
         return parser
 
